pub struct HeapArray {
pub pointer: MemoryAddress,
pub size: SemiFlattenedLength,
}Expand description
A fixed-sized array starting from a Brillig memory location.
Fields
pointer: MemoryAddressPointer to a memory address which hold the address to the start of the items in the array.
That is to say, the address retrieved from the pointer doesn’t need any more offsetting.
size: SemiFlattenedLengthStatically known size of the array.