pub struct HeapVector {
pub pointer: MemoryAddress,
pub size: MemoryAddress,
}Expand description
A memory-sized vector passed starting from a Brillig memory location and with a memory-held size
Fields
pointer: MemoryAddresssize: MemoryAddressTrait Implementations
Sourceimpl Clone for HeapVector
impl Clone for HeapVector
Sourcefn clone(&self) -> HeapVector
fn clone(&self) -> HeapVector
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for HeapVector
Sourceimpl Debug for HeapVector
impl Debug for HeapVector
Sourceimpl<'de> Deserialize<'de> for HeapVector
impl<'de> Deserialize<'de> for HeapVector
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for HeapVector
Sourceimpl PartialEq for HeapVector
impl PartialEq for HeapVector
Sourcefn eq(&self, other: &HeapVector) -> bool
fn eq(&self, other: &HeapVector) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for HeapVector
impl Serialize for HeapVector
impl StructuralPartialEq for HeapVector